==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/CategoryXAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategoryAxisBaseDescriptionMetadata } from "./CategoryAxisBaseDescriptionMetadata";
import { CategoryXAxisDescription } from "./CategoryXAxisDescription";
/**
 * @hidden
 */
export let CategoryXAxisDescriptionMetadata = /*@__PURE__*/ (() => {
    class CategoryXAxisDescriptionMetadata extends Base {
        static b(a) {
            if (CategoryXAxisDescriptionMetadata.a == null) {
                CategoryXAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CategoryXAxisDescriptionMetadata.c(CategoryXAxisDescriptionMetadata.a);
            }
            if (a.k(CategoryXAxisDescriptionMetadata.a)) {
                return;
            }
            a.ab(CategoryXAxisDescriptionMetadata.a);
        }
        static c(a) {
            CategoryAxisBaseDescriptionMetadata.c(a);
            a.item("ZoomMaximumCategoryRange", "Number:double");
            a.item("ZoomMaximumItemSpan", "Number:double");
            a.item("ZoomToCategoryRange", "Number:double");
            a.item("ZoomToCategoryStart", "Number:double");
            a.item("ZoomToItemSpan", "Number:double");
            a.item("Interval", "Number:double");
            a.item("ActualInterval", "Number:double");
            a.item("MinorInterval", "Number:double");
            a.item("ActualMinorInterval", "Number:double");
            a.item("ActualIntervalChangeRef", "EventRef::actualIntervalChange");
            a.item("ActualMinorIntervalChangeRef", "EventRef::actualMinorIntervalChange");
        }
        static d(a) {
            CategoryXAxisDescriptionMetadata.b(a);
            a.ad("CategoryXAxis", () => new CategoryXAxisDescription());
            a.ac("CategoryXAxis", CategoryXAxisDescriptionMetadata.a);
        }
    }
    CategoryXAxisDescriptionMetadata.$t = /*@__PURE__*/ markType(CategoryXAxisDescriptionMetadata, 'CategoryXAxisDescriptionMetadata');
    CategoryXAxisDescriptionMetadata.a = null;
    return CategoryXAxisDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/CategoryXAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategoryAxisBaseDescriptionMetadata } from "./CategoryAxisBaseDescriptionMetadata";
import { CategoryXAxisDescription } from "./CategoryXAxisDescription";
/**
 * @hidden
 */
export let CategoryXAxisDescriptionMetadata = /*@__PURE__*/ (() => {
    class CategoryXAxisDescriptionMetadata extends Base {
        static b(a) {
            if (CategoryXAxisDescriptionMetadata.a == null) {
                CategoryXAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CategoryXAxisDescriptionMetadata.c(CategoryXAxisDescriptionMetadata.a);
            }
            if (a.k(CategoryXAxisDescriptionMetadata.a)) {
                return;
            }
            a.ac(CategoryXAxisDescriptionMetadata.a);
        }
        static c(a) {
            CategoryAxisBaseDescriptionMetadata.c(a);
            a.item("ZoomMaximumCategoryRange", "Number:double");
            a.item("ZoomMaximumItemSpan", "Number:double");
            a.item("ZoomToCategoryRange", "Number:double");
            a.item("ZoomToCategoryStart", "Number:double");
            a.item("ZoomToItemSpan", "Number:double");
            a.item("Interval", "Number:double");
            a.item("ActualInterval", "Number:double");
            a.item("MinorInterval", "Number:double");
            a.item("ActualMinorInterval", "Number:double");
            a.item("ActualIntervalChangeRef", "EventRef::actualIntervalChange");
            a.item("ActualMinorIntervalChangeRef", "EventRef::actualMinorIntervalChange");
        }
        static d(a) {
            CategoryXAxisDescriptionMetadata.b(a);
            a.ae("CategoryXAxis", () => new CategoryXAxisDescription());
            a.ad("CategoryXAxis", CategoryXAxisDescriptionMetadata.a);
        }
    }
    CategoryXAxisDescriptionMetadata.$t = /*@__PURE__*/ markType(CategoryXAxisDescriptionMetadata, 'CategoryXAxisDescriptionMetadata');
    CategoryXAxisDescriptionMetadata.a = null;
    return CategoryXAxisDescriptionMetadata;
})();
